kem/keypair library
Classes
- ASECiphertextKEM
- This class represents the ciphertext for the ASE KEM scheme. It contains a polynomial vector u and a polynomial v.
- ASEKeyPair
- This class represents the key pair for the ASE KEM scheme. It contains a public key and a private key.
- ASEPrivateKey
- This class represents the private key for the ASE KEM scheme. It contains a polynomial vector s.
- ASEPublicKey
- This class represents the public key for the ASE KEM scheme. It contains a list of polynomial vectors A and a polynomial b.