ASECiphertextKEM class

This class represents the ciphertext for the ASE KEM scheme. It contains a polynomial vector u and a polynomial v.

Constructors

ASECiphertextKEM(PolyVec u, Poly v)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
u PolyVec
final
v Poly
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited