ASEKeyPair class

This class represents the key pair for the ASE KEM scheme. It contains a public key and a private key.

Constructors

ASEKeyPair(ASEPublicKey pk, ASEPrivateKey sk)

Properties

hashCode int
The hash code for this object.
no setterinherited
pk ASEPublicKey
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sk ASEPrivateKey
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited