ASEPublicKey class

This class represents the public key for the ASE KEM scheme. It contains a list of polynomial vectors A and a polynomial b.

Constructors

ASEPublicKey(List<PolyVec> A, PolyVec b)

Properties

A List<PolyVec>
final
b PolyVec
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited