PolyVec class

Constructors

PolyVec([List<Poly>? v])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vec List<Poly>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator +(PolyVec o) PolyVec
operator ==(Object other) bool
The equality operator.
inherited

Static Methods

mulMatrix(List<PolyVec> A, PolyVec s) PolyVec