ASEPublicKey class
This class represents the public key for the ASE KEM scheme. It contains a list of polynomial vectors A and a polynomial b.
Constructors
-
ASEPublicKey(List<
PolyVec> A, PolyVec b)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited